@@ -22,8 +22,8 @@
 #
 # Created:     26/09/2019
 # -------------------------------------------------------------------------------
-import gdal, gdalconst
-import osr, ogr
+from osgeo import gdal, gdalconst
+from osgeo import osr, ogr
 import numpy as np
 from .strings import *
 from .filesystem import *
@@ -365,6 +365,10 @@ def renderer_v2(geomtype="POINT", options=None):
 
         if options and "type" in options and options["type"]=="singleSymbol":
             return singleSymbol( options )
+        if options and "type" in options and options["type"]=="categorizedSymbol":
+            return categorizedSymbol( options )
+        if options and "type" in options and options["type"]=="graduatedSymbol":
+            return graduatedSymbol( options )
 
         return {
             "forceraster": 0,
